# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_studio
from vrt_lss_studio.models.service_statistics import ServiceStatistics  # noqa: E501
from vrt_lss_studio.rest import ApiException

class TestServiceStatistics(unittest.TestCase):
    """ServiceStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ServiceStatistics
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_studio.models.service_statistics.ServiceStatistics()  # noqa: E501
        if include_optional :
            return ServiceStatistics(
                service = 'LASTMILE', 
                methods = [
                    vrt_lss_studio.models.method_statistics.MethodStatistics(
                        method = 'PLAN', 
                        unique_points_per_day = 1500, 
                        points_per_day = 1500, )
                    ]
            )
        else :
            return ServiceStatistics(
                service = 'LASTMILE',
                methods = [
                    vrt_lss_studio.models.method_statistics.MethodStatistics(
                        method = 'PLAN', 
                        unique_points_per_day = 1500, 
                        points_per_day = 1500, )
                    ],
        )

    def testServiceStatistics(self):
        """Test ServiceStatistics"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
