# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_studio
from vrt_lss_studio.models.user_report_filter import UserReportFilter  # noqa: E501
from vrt_lss_studio.rest import ApiException

class TestUserReportFilter(unittest.TestCase):
    """UserReportFilter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserReportFilter
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_studio.models.user_report_filter.UserReportFilter()  # noqa: E501
        if include_optional :
            return UserReportFilter(
                name = 'UsageReport', 
                date_window = vrt_lss_studio.models.date_window.DateWindow(
                    from = 'Sun Feb 21 03:00:00 MSK 2021', 
                    to = 'Thu Feb 25 03:00:00 MSK 2021', )
            )
        else :
            return UserReportFilter(
                name = 'UsageReport',
        )

    def testUserReportFilter(self):
        """Test UserReportFilter"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
