# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_studio
from vrt_lss_studio.models.inline_response403 import InlineResponse403  # noqa: E501
from vrt_lss_studio.rest import ApiException

class TestInlineResponse403(unittest.TestCase):
    """InlineResponse403 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse403
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_studio.models.inline_response403.InlineResponse403()  # noqa: E501
        if include_optional :
            return InlineResponse403(
                tracedata = vrt_lss_studio.models.trace_data.TraceData(
                    code = 'client_server_service_time_uuid', 
                    client = 'client_name', 
                    server = 'server_name', 
                    service = 'LASTMILE', 
                    method = 'PLAN', 
                    time = '2021-02-21T09:30+03:00', ), 
                message = 'Forbidden', 
                code = 1403
            )
        else :
            return InlineResponse403(
                code = 1403,
        )

    def testInlineResponse403(self):
        """Test InlineResponse403"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
